Authors
=======

This file contains the list of people involved in the development
of pytest-elasticsearch along its history.

* Grzegorz Sliwiński
* Paweł Wilczyński
* Tomasz Karbownicki
* Karolina Blümke
* Marcin Maślany
* Damian Skrzypczak